# Mini Django Accounts

[![build status](https://gitlab.com/chaosengine256/mini-django-accounts/badges/master/build.svg)](https://gitlab.com/chaosengine256/mini-django-accounts/commits/master)
[![coverage report](https://gitlab.com/chaosengine256/mini-django-accounts/badges/master/coverage.svg)](https://gitlab.com/chaosengine256/mini-django-accounts/commits/master)
